@@ -24,7 +24,7 @@ from cura import LayerPolygon
 
 import numpy
 from time import time
-from cura.Settings.ExtrudersModel import ExtrudersModel
+from cura.Machines.Models.ExtrudersModel import ExtrudersModel
 catalog = i18nCatalog("cura")
 
 
@@ -137,6 +137,7 @@ class ProcessSlicedLayersJob(Job):
                 extruder = polygon.extruder
 
                 line_types = numpy.fromstring(polygon.line_type, dtype="u1")  # Convert bytearray to numpy array
+
                 line_types = line_types.reshape((-1,1))
 
                 points = numpy.fromstring(polygon.points, dtype="f4")  # Convert bytearray to numpy array
