@@ -25,15 +25,14 @@ class FirmwareUpdateCheckerJob(Job):
     ZERO_VERSION = Version(STRING_ZERO_VERSION)
     EPSILON_VERSION = Version(STRING_EPSILON_VERSION)
 
-    def __init__(self, container, silent, machine_name, metadata, callback) -> None:
+    def __init__(self, silent, machine_name, metadata, callback) -> None:
         super().__init__()
-        self._container = container
         self.silent = silent
         self._callback = callback
 
         self._machine_name = machine_name
         self._metadata = metadata
-        self._lookups = None  # type:Optional[FirmwareUpdateCheckerLookup]
+        self._lookups = FirmwareUpdateCheckerLookup(self._machine_name, self._metadata)
         self._headers = {}  # type:Dict[str, str]  # Don't set headers yet.
 
     def getUrlResponse(self, url: str) -> str:
@@ -45,7 +44,6 @@ class FirmwareUpdateCheckerJob(Job):
             result = response.read().decode("utf-8")
         except URLError:
             Logger.log("w", "Could not reach '{0}', if this URL is old, consider removal.".format(url))
-
         return result
 
     def parseVersionResponse(self, response: str) -> Version:
@@ -70,9 +68,6 @@ class FirmwareUpdateCheckerJob(Job):
         return max_version
 
     def run(self):
-        if self._lookups is None:
-            self._lookups = FirmwareUpdateCheckerLookup(self._machine_name, self._metadata)
-
         try:
             # Initialize a Preference that stores the last version checked for this printer.
             Application.getInstance().getPreferences().addPreference(
@@ -83,13 +78,10 @@ class FirmwareUpdateCheckerJob(Job):
             application_version = Application.getInstance().getVersion()
             self._headers = {"User-Agent": "%s - %s" % (application_name, application_version)}
 
-            # get machine name from the definition container
-            machine_name = self._container.definition.getName()
-
             # If it is not None, then we compare between the checked_version and the current_version
             machine_id = self._lookups.getMachineId()
             if machine_id is not None:
-                Logger.log("i", "You have a(n) {0} in the printer list. Let's check the firmware!".format(machine_name))
+                Logger.log("i", "You have a(n) {0} in the printer list. Do firmware-check.".format(self._machine_name))
 
                 current_version = self.getCurrentVersion()
 
@@ -105,18 +97,20 @@ class FirmwareUpdateCheckerJob(Job):
                 # If the checked_version is "", it's because is the first time we check firmware and in this case
                 # we will not show the notification, but we will store it for the next time
                 Application.getInstance().getPreferences().setValue(setting_key_str, current_version)
-                Logger.log("i", "Reading firmware version of %s: checked = %s - latest = %s", machine_name, checked_version, current_version)
+                Logger.log("i", "Reading firmware version of %s: checked = %s - latest = %s",
+                           self._machine_name, checked_version, current_version)
 
                 # The first time we want to store the current version, the notification will not be shown,
                 # because the new version of Cura will be release before the firmware and we don't want to
                 # notify the user when no new firmware version is available.
                 if (checked_version != "") and (checked_version != current_version):
                     Logger.log("i", "SHOWING FIRMWARE UPDATE MESSAGE")
-                    message = FirmwareUpdateCheckerMessage(machine_id, machine_name, self._lookups.getRedirectUserUrl())
+                    message = FirmwareUpdateCheckerMessage(machine_id, self._machine_name,
+                                                           self._lookups.getRedirectUserUrl())
                     message.actionTriggered.connect(self._callback)
                     message.show()
             else:
-                Logger.log("i", "No machine with name {0} in list of firmware to check.".format(machine_name))
+                Logger.log("i", "No machine with name {0} in list of firmware to check.".format(self._machine_name))
 
         except Exception as e:
             Logger.log("w", "Failed to check for new version: %s", e)
