@@ -50,7 +50,6 @@ class Toolbox(QObject, Extension):
         self._request_headers = [] # type: List[Tuple[bytes, bytes]]
         self._updateRequestHeader()
 
-
         self._request_urls = {}  # type: Dict[str, QUrl]
         self._to_update = []  # type: List[str] # Package_ids that are waiting to be updated
         self._old_plugin_ids = set()  # type: Set[str]
@@ -106,6 +105,7 @@ class Toolbox(QObject, Extension):
 
         self._application.initializationFinished.connect(self._onAppInitialized)
         self._application.getCuraAPI().account.loginStateChanged.connect(self._updateRequestHeader)
+        self._application.getCuraAPI().account.accessTokenChanged.connect(self._updateRequestHeader)
 
     # Signals:
     # --------------------------------------------------------------------------
@@ -190,8 +190,10 @@ class Toolbox(QObject, Extension):
             "packages": QUrl("{base_url}/packages".format(base_url = self._api_url))
         }
 
-    @pyqtSlot()
-    def browsePackages(self) -> None:
+        # Request the latest and greatest!
+        self._fetchPackageData()
+
+    def _fetchPackageData(self):
         # Create the network manager:
         # This was formerly its own function but really had no reason to be as
         # it was never called more than once ever.
@@ -209,6 +211,10 @@ class Toolbox(QObject, Extension):
         # Gather installed packages:
         self._updateInstalledModels()
 
+    @pyqtSlot()
+    def browsePackages(self) -> None:
+        self._fetchPackageData()
+
         if not self._dialog:
             self._dialog = self._createDialog("Toolbox.qml")
 
@@ -455,36 +461,6 @@ class Toolbox(QObject, Extension):
                 break
         return remote_package
 
-    # Checks
-    # --------------------------------------------------------------------------
-    @pyqtSlot(str, result = bool)
-    def canUpdate(self, package_id: str) -> bool:
-        local_package = self._package_manager.getInstalledPackageInfo(package_id)
-        if local_package is None:
-            local_package = self.getOldPluginPackageMetadata(package_id)
-            if local_package is None:
-                return False
-
-        remote_package = self.getRemotePackage(package_id)
-        if remote_package is None:
-            return False
-
-        local_version = Version(local_package["package_version"])
-        remote_version = Version(remote_package["package_version"])
-        can_upgrade = False
-        if remote_version > local_version:
-            can_upgrade = True
-        # A package with the same version can be built to have different SDK versions. So, for a package with the same
-        # version, we also need to check if the current one has a lower SDK version. If so, this package should also
-        # be upgradable.
-        elif remote_version == local_version:
-            # First read sdk_version_semver. If that doesn't exist, read just sdk_version (old version system).
-            remote_sdk_version = Version(remote_package.get("sdk_version_semver", remote_package.get("sdk_version", 0)))
-            local_sdk_version = Version(local_package.get("sdk_version_semver", local_package.get("sdk_version", 0)))
-            can_upgrade = local_sdk_version < remote_sdk_version
-
-        return can_upgrade
-
     @pyqtSlot(str, result = bool)
     def canDowngrade(self, package_id: str) -> bool:
         # If the currently installed version is higher than the bundled version (if present), the we can downgrade
@@ -584,9 +560,15 @@ class Toolbox(QObject, Extension):
         if self._download_reply:
             try:
                 self._download_reply.downloadProgress.disconnect(self._onDownloadProgress)
-            except TypeError:  # Raised when the method is not connected to the signal yet.
+            except (TypeError, RuntimeError):  # Raised when the method is not connected to the signal yet.
                 pass  # Don't need to disconnect.
-            self._download_reply.abort()
+            try:
+                self._download_reply.abort()
+            except RuntimeError:
+                # In some cases the garbage collector is a bit to agressive, which causes the dowload_reply
+                # to be deleted (especially if the machine has been put to sleep). As we don't know what exactly causes
+                # this (The issue probably lives in the bowels of (py)Qt somewhere), we can only catch and ignore it.
+                pass
         self._download_reply = None
         self._download_request = None
         self.setDownloadProgress(0)
@@ -632,11 +614,12 @@ class Toolbox(QObject, Extension):
                             self._server_response_data[response_type] = json_data["data"]
                             self._models[response_type].setMetadata(self._server_response_data[response_type])
 
-                            if response_type is "packages":
+                            if response_type == "packages":
                                 self._models[response_type].setFilter({"type": "plugin"})
                                 self.reBuildMaterialsModels()
                                 self.reBuildPluginsModels()
-                            elif response_type is "authors":
+                                self._notifyPackageManager()
+                            elif response_type == "authors":
                                 self._models[response_type].setFilter({"package_types": "material"})
                                 self._models[response_type].setFilter({"tags": "generic"})
 
@@ -649,12 +632,18 @@ class Toolbox(QObject, Extension):
                             Logger.log("w", "Received invalid JSON for %s.", response_type)
                             break
                     else:
+                        Logger.log("w", "Unable to connect with the server, we got a response code %s while trying to connect to %s", reply.attribute(QNetworkRequest.HttpStatusCodeAttribute), reply.url())
                         self.setViewPage("errored")
                         self.resetDownload()
         elif reply.operation() == QNetworkAccessManager.PutOperation:
             # Ignore any operation that is not a get operation
             pass
 
+    # This function goes through all known remote versions of a package and notifies the package manager of this change
+    def _notifyPackageManager(self):
+        for package in self._server_response_data["packages"]:
+            self._package_manager.addAvailablePackageVersion(package["package_id"], Version(package["package_version"]))
+
     def _onDownloadProgress(self, bytes_sent: int, bytes_total: int) -> None:
         if bytes_total > 0:
             new_progress = bytes_sent / bytes_total * 100
