@@ -1,14 +1,14 @@
-# Copyright (c) 2018 Ultimaker B.V.
+# Copyright (c) 2019 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
+
 import json
 import os
 from typing import Dict, TYPE_CHECKING, Set, Optional
-
 from PyQt5.QtNetwork import QNetworkReply, QNetworkRequest
 
-from UM.Application import Application
 from UM.Job import Job
 from UM.Logger import Logger
+from cura.CuraApplication import CuraApplication
 
 # Absolute imports don't work in plugins
 from .Models import ClusterMaterial, LocalMaterial
@@ -86,8 +86,8 @@ class SendMaterialJob(Job):
     #
     #   \param materials_to_send A set with id's of materials that must be sent.
     def _sendMaterials(self, materials_to_send: Set[str]) -> None:
-        container_registry = Application.getInstance().getContainerRegistry()
-        material_manager = Application.getInstance().getMaterialManager()
+        container_registry = CuraApplication.getInstance().getContainerRegistry()
+        material_manager = CuraApplication.getInstance().getMaterialManager()
         material_group_dict = material_manager.getAllMaterialGroups()
 
         for root_material_id in material_group_dict:
@@ -166,7 +166,7 @@ class SendMaterialJob(Job):
     #   \return a dictionary of LocalMaterial objects by GUID
     def _getLocalMaterials(self) -> Dict[str, LocalMaterial]:
         result = {}  # type: Dict[str, LocalMaterial]
-        material_manager = Application.getInstance().getMaterialManager()
+        material_manager = CuraApplication.getInstance().getMaterialManager()
 
         material_group_dict = material_manager.getAllMaterialGroups()
 
