@@ -1,19 +1,21 @@
-# Copyright (c) 2018 Ultimaker B.V.
+# Copyright (c) 2019 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
-from typing import Optional, Callable, Tuple, Dict, Any, List, TYPE_CHECKING
 
 from http.server import BaseHTTPRequestHandler
+from typing import Optional, Callable, Tuple, Dict, Any, List, TYPE_CHECKING
 from urllib.parse import parse_qs, urlparse
 
 from cura.OAuth2.Models import AuthenticationResponse, ResponseData, HTTP_STATUS
+from UM.i18n import i18nCatalog
 
 if TYPE_CHECKING:
     from cura.OAuth2.Models import ResponseStatus
     from cura.OAuth2.AuthorizationHelpers import AuthorizationHelpers
 
+catalog = i18nCatalog("cura")
 
-#   This handler handles all HTTP requests on the local web server.
-#     It also requests the access token for the 2nd stage of the OAuth flow.
+##  This handler handles all HTTP requests on the local web server.
+#   It also requests the access token for the 2nd stage of the OAuth flow.
 class AuthorizationRequestHandler(BaseHTTPRequestHandler):
     def __init__(self, request, client_address, server) -> None:
         super().__init__(request, client_address, server)
@@ -47,9 +49,9 @@ class AuthorizationRequestHandler(BaseHTTPRequestHandler):
             # This will cause the server to shut down, so we do it at the very end of the request handling.
             self.authorization_callback(token_response)
 
-    #   Handler for the callback URL redirect.
-    #   \param query: Dict containing the HTTP query parameters.
-    #   \return: HTTP ResponseData containing a success page to show to the user.
+    ##  Handler for the callback URL redirect.
+    #   \param query Dict containing the HTTP query parameters.
+    #   \return HTTP ResponseData containing a success page to show to the user.
     def _handleCallback(self, query: Dict[Any, List]) -> Tuple[ResponseData, Optional[AuthenticationResponse]]:
         code = self._queryGet(query, "code")
         if code and self.authorization_helpers is not None and self.verification_code is not None:
@@ -60,30 +62,30 @@ class AuthorizationRequestHandler(BaseHTTPRequestHandler):
         elif self._queryGet(query, "error_code") == "user_denied":
             # Otherwise we show an error message (probably the user clicked "Deny" in the auth dialog).
             token_response = AuthenticationResponse(
-                success=False,
-                err_message="Please give the required permissions when authorizing this application."
+                success = False,
+                err_message = catalog.i18nc("@message", "Please give the required permissions when authorizing this application.")
             )
 
         else:
             # We don't know what went wrong here, so instruct the user to check the logs.
             token_response = AuthenticationResponse(
-                success=False,
-                error_message="Something unexpected happened when trying to log in, please try again."
+                success = False,
+                error_message = catalog.i18nc("@message", "Something unexpected happened when trying to log in, please try again.")
             )
         if self.authorization_helpers is None:
             return ResponseData(), token_response
 
         return ResponseData(
-            status=HTTP_STATUS["REDIRECT"],
-            data_stream=b"Redirecting...",
-            redirect_uri=self.authorization_helpers.settings.AUTH_SUCCESS_REDIRECT if token_response.success else
+            status = HTTP_STATUS["REDIRECT"],
+            data_stream = b"Redirecting...",
+            redirect_uri = self.authorization_helpers.settings.AUTH_SUCCESS_REDIRECT if token_response.success else
             self.authorization_helpers.settings.AUTH_FAILED_REDIRECT
         ), token_response
 
+    ##  Handle all other non-existing server calls.
     @staticmethod
-    #   Handle all other non-existing server calls.
     def _handleNotFound() -> ResponseData:
-        return ResponseData(status=HTTP_STATUS["NOT_FOUND"], content_type="text/html", data_stream=b"Not found.")
+        return ResponseData(status = HTTP_STATUS["NOT_FOUND"], content_type = "text/html", data_stream = b"Not found.")
 
     def _sendHeaders(self, status: "ResponseStatus", content_type: str, redirect_uri: str = None) -> None:
         self.send_response(status.code, status.message)
@@ -95,7 +97,7 @@ class AuthorizationRequestHandler(BaseHTTPRequestHandler):
     def _sendData(self, data: bytes) -> None:
         self.wfile.write(data)
 
+    ##  Convenience helper for getting values from a pre-parsed query string
     @staticmethod
-    #   Convenience Helper for getting values from a pre-parsed query string
-    def _queryGet(query_data: Dict[Any, List], key: str, default: Optional[str]=None) -> Optional[str]:
+    def _queryGet(query_data: Dict[Any, List], key: str, default: Optional[str] = None) -> Optional[str]:
         return query_data.get(key, [default])[0]
