@@ -25,18 +25,17 @@ if TYPE_CHECKING:
     from UM.Preferences import Preferences
 
 
+##  The authorization service is responsible for handling the login flow,
+#   storing user credentials and providing account information.
 class AuthorizationService:
-    """
-    The authorization service is responsible for handling the login flow,
-    storing user credentials and providing account information.
-    """
-
     # Emit signal when authentication is completed.
     onAuthStateChanged = Signal()
 
     # Emit signal when authentication failed.
     onAuthenticationError = Signal()
 
+    accessTokenChanged = Signal()
+
     def __init__(self, settings: "OAuth2Settings", preferences: Optional["Preferences"] = None) -> None:
         self._settings = settings
         self._auth_helpers = AuthorizationHelpers(settings)
@@ -60,16 +59,18 @@ class AuthorizationService:
         if self._preferences:
             self._preferences.addPreference(self._settings.AUTH_DATA_PREFERENCE_KEY, "{}")
 
-    #   Get the user profile as obtained from the JWT (JSON Web Token).
+    ##  Get the user profile as obtained from the JWT (JSON Web Token).
     #   If the JWT is not yet parsed, calling this will take care of that.
     #   \return UserProfile if a user is logged in, None otherwise.
     #   \sa _parseJWT
     def getUserProfile(self) -> Optional["UserProfile"]:
         if not self._user_profile:
+            # If no user profile was stored locally, we try to get it from JWT.
             try:
                 self._user_profile = self._parseJWT()
             except requests.exceptions.ConnectionError:
                 # Unable to get connection, can't login.
+                Logger.logException("w", "Unable to validate user data with the remote server.")
                 return None
 
         if not self._user_profile and self._auth_data:
@@ -80,11 +81,12 @@ class AuthorizationService:
 
         return self._user_profile
 
-    #   Tries to parse the JWT (JSON Web Token) data, which it does if all the needed data is there.
+    ##  Tries to parse the JWT (JSON Web Token) data, which it does if all the needed data is there.
     #   \return UserProfile if it was able to parse, None otherwise.
     def _parseJWT(self) -> Optional["UserProfile"]:
         if not self._auth_data or self._auth_data.access_token is None:
             # If no auth data exists, we should always log in again.
+            Logger.log("d", "There was no auth data or access token")
             return None
         user_data = self._auth_helpers.parseJWT(self._auth_data.access_token)
         if user_data:
@@ -92,15 +94,19 @@ class AuthorizationService:
             return user_data
         # The JWT was expired or invalid and we should request a new one.
         if self._auth_data.refresh_token is None:
+            Logger.log("w", "There was no refresh token in the auth data.")
             return None
         self._auth_data = self._auth_helpers.getAccessTokenUsingRefreshToken(self._auth_data.refresh_token)
         if not self._auth_data or self._auth_data.access_token is None:
+            Logger.log("w", "Unable to use the refresh token to get a new access token.")
             # The token could not be refreshed using the refresh token. We should login again.
             return None
-
+        # Ensure it gets stored as otherwise we only have it in memory. The stored refresh token has been deleted
+        # from the server already.
+        self._storeAuthData(self._auth_data)
         return self._auth_helpers.parseJWT(self._auth_data.access_token)
 
-    #   Get the access token as provided by the response data.
+    ##  Get the access token as provided by the repsonse data.
     def getAccessToken(self) -> Optional[str]:
         if self._auth_data is None:
             Logger.log("d", "No auth data to retrieve the access_token from")
@@ -116,7 +122,7 @@ class AuthorizationService:
 
         return self._auth_data.access_token if self._auth_data else None
 
-    #   Try to refresh the access token. This should be used when it has expired.
+    ##  Try to refresh the access token. This should be used when it has expired.
     def refreshAccessToken(self) -> None:
         if self._auth_data is None or self._auth_data.refresh_token is None:
             Logger.log("w", "Unable to refresh access token, since there is no refresh token.")
@@ -124,17 +130,18 @@ class AuthorizationService:
         response = self._auth_helpers.getAccessTokenUsingRefreshToken(self._auth_data.refresh_token)
         if response.success:
             self._storeAuthData(response)
-            self.onAuthStateChanged.emit(logged_in=True)
+            self.onAuthStateChanged.emit(logged_in = True)
         else:
+            Logger.log("w", "Failed to get a new access token from the server.")
             self.onAuthStateChanged.emit(logged_in = False)
 
-    #   Delete the authentication data that we have stored locally (eg; logout)
+    ##  Delete the authentication data that we have stored locally (eg; logout)
     def deleteAuthData(self) -> None:
         if self._auth_data is not None:
             self._storeAuthData()
-            self.onAuthStateChanged.emit(logged_in=False)
+            self.onAuthStateChanged.emit(logged_in = False)
 
-    #   Start the flow to become authenticated. This will start a new webbrowser tap, prompting the user to login.
+    ##  Start the flow to become authenticated. This will start a new webbrowser tap, prompting the user to login.
     def startAuthorizationFlow(self) -> None:
         Logger.log("d", "Starting new OAuth2 flow...")
 
@@ -161,16 +168,16 @@ class AuthorizationService:
         # Start a local web server to receive the callback URL on.
         self._server.start(verification_code)
 
-    #   Callback method for the authentication flow.
+    ##  Callback method for the authentication flow.
     def _onAuthStateChanged(self, auth_response: AuthenticationResponse) -> None:
         if auth_response.success:
             self._storeAuthData(auth_response)
-            self.onAuthStateChanged.emit(logged_in=True)
+            self.onAuthStateChanged.emit(logged_in = True)
         else:
-            self.onAuthenticationError.emit(logged_in=False, error_message=auth_response.err_message)
+            self.onAuthenticationError.emit(logged_in = False, error_message = auth_response.err_message)
         self._server.stop()  # Stop the web server at all times.
 
-    #   Load authentication data from preferences.
+    ##  Load authentication data from preferences.
     def loadAuthDataFromPreferences(self) -> None:
         if self._preferences is None:
             Logger.log("e", "Unable to load authentication data, since no preference has been set!")
@@ -182,7 +189,7 @@ class AuthorizationService:
                 # Also check if we can actually get the user profile information.
                 user_profile = self.getUserProfile()
                 if user_profile is not None:
-                    self.onAuthStateChanged.emit(logged_in=True)
+                    self.onAuthStateChanged.emit(logged_in = True)
                 else:
                     if self._unable_to_get_data_message is not None:
                         self._unable_to_get_data_message.hide()
@@ -194,8 +201,9 @@ class AuthorizationService:
         except ValueError:
             Logger.logException("w", "Could not load auth data from preferences")
 
-    #   Store authentication data in preferences.
+    ##  Store authentication data in preferences.
     def _storeAuthData(self, auth_data: Optional[AuthenticationResponse] = None) -> None:
+        Logger.log("d", "Attempting to store the auth data")
         if self._preferences is None:
             Logger.log("e", "Unable to save authentication data, since no preference has been set!")
             return
@@ -208,6 +216,8 @@ class AuthorizationService:
             self._user_profile = None
             self._preferences.resetPreference(self._settings.AUTH_DATA_PREFERENCE_KEY)
 
+        self.accessTokenChanged.emit()
+
     def _onMessageActionTriggered(self, _, action):
         if action == "retry":
             self.loadAuthDataFromPreferences()
